/****************************************************************************
** Meta object code from reading C++ file 'documenthandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../marknote-1.5.2/src/documenthandler.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documenthandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DocumentHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto DocumentHandler::qt_create_metaobjectdata<qt_meta_tag_ZN15DocumentHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DocumentHandler",
        "QML.Element",
        "anonymous",
        "documentChanged",
        "",
        "textAreaChanged",
        "cursorPositionChanged",
        "selectionStartChanged",
        "selectionEndChanged",
        "fontFamilyChanged",
        "textColorChanged",
        "fontSizeChanged",
        "textChanged",
        "fileUrlChanged",
        "loaded",
        "text",
        "format",
        "error",
        "message",
        "modifiedChanged",
        "searchMatchCountChanged",
        "searchCurrentMatchChanged",
        "focusUp",
        "focusDown",
        "copy",
        "cut",
        "undo",
        "redo",
        "moveCursor",
        "position",
        "selectCursor",
        "start",
        "end",
        "internalLinkActivated",
        "noteName",
        "load",
        "QUrl",
        "fileUrl",
        "saveAs",
        "anchorAt",
        "QPointF",
        "p",
        "clearUndoRedoStacks",
        "findText",
        "searchTerm",
        "findNext",
        "findPrevious",
        "clearSearch",
        "replaceCurrent",
        "replaceText",
        "replaceAll",
        "pasteFromClipboard",
        "slotMouseMovedWithControl",
        "slotMouseMovedWithControlReleased",
        "document",
        "QQuickTextDocument*",
        "textArea",
        "QQuickItem*",
        "cursorPosition",
        "selectionStart",
        "selectionEnd",
        "textColor",
        "QColor",
        "fontFamily",
        "fontSize",
        "fileName",
        "fileType",
        "modified",
        "searchMatchCount",
        "searchCurrentMatch"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textAreaChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionStartChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEndChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textColorChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileUrlChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void(const QString &, int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'modifiedChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchMatchCountChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchCurrentMatchChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusUp'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focusDown'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copy'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cut'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undo'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'redo'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveCursor'
        QtMocHelpers::SignalData<void(int)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'selectCursor'
        QtMocHelpers::SignalData<void(int, int)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 }, { QMetaType::Int, 32 },
        }}),
        // Signal 'internalLinkActivated'
        QtMocHelpers::SignalData<void(const QString &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QUrl &)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void(const QUrl &)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Method 'anchorAt'
        QtMocHelpers::MethodData<QString(const QPointF &) const>(39, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 40, 41 },
        }}),
        // Method 'clearUndoRedoStacks'
        QtMocHelpers::MethodData<void()>(42, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'findText'
        QtMocHelpers::MethodData<int(const QString &)>(43, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 44 },
        }}),
        // Method 'findNext'
        QtMocHelpers::MethodData<void()>(45, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'findPrevious'
        QtMocHelpers::MethodData<void()>(46, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearSearch'
        QtMocHelpers::MethodData<void()>(47, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'replaceCurrent'
        QtMocHelpers::MethodData<void(const QString &)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Method 'replaceAll'
        QtMocHelpers::MethodData<int(const QString &)>(50, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 49 },
        }}),
        // Method 'pasteFromClipboard'
        QtMocHelpers::MethodData<void()>(51, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotMouseMovedWithControl'
        QtMocHelpers::MethodData<void(QPointF)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 40, 29 },
        }}),
        // Method 'slotMouseMovedWithControlReleased'
        QtMocHelpers::MethodData<void()>(53, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'document'
        QtMocHelpers::PropertyData<QQuickTextDocument*>(54, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'textArea'
        QtMocHelpers::PropertyData<QQuickItem*>(56, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'cursorPosition'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'selectionStart'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'selectionEnd'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'fontSize'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'fileType'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'fileUrl'
        QtMocHelpers::PropertyData<QUrl>(37, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'modified'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'searchMatchCount'
        QtMocHelpers::PropertyData<int>(68, QMetaType::Int, QMC::DefaultPropertyFlags, 13),
        // property 'searchCurrentMatch'
        QtMocHelpers::PropertyData<int>(69, QMetaType::Int, QMC::DefaultPropertyFlags, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DocumentHandler, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DocumentHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DocumentHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DocumentHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DocumentHandlerE_t>.metaTypes,
    nullptr
} };

void DocumentHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentChanged(); break;
        case 1: _t->textAreaChanged(); break;
        case 2: _t->cursorPositionChanged(); break;
        case 3: _t->selectionStartChanged(); break;
        case 4: _t->selectionEndChanged(); break;
        case 5: _t->fontFamilyChanged(); break;
        case 6: _t->textColorChanged(); break;
        case 7: _t->fontSizeChanged(); break;
        case 8: _t->textChanged(); break;
        case 9: _t->fileUrlChanged(); break;
        case 10: _t->loaded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->modifiedChanged(); break;
        case 13: _t->searchMatchCountChanged(); break;
        case 14: _t->searchCurrentMatchChanged(); break;
        case 15: _t->focusUp(); break;
        case 16: _t->focusDown(); break;
        case 17: _t->copy(); break;
        case 18: _t->cut(); break;
        case 19: _t->undo(); break;
        case 20: _t->redo(); break;
        case 21: _t->moveCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->selectCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 23: _t->internalLinkActivated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->load((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 25: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 26: { QString _r = _t->anchorAt((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->clearUndoRedoStacks(); break;
        case 28: { int _r = _t->findText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->findNext(); break;
        case 30: _t->findPrevious(); break;
        case 31: _t->clearSearch(); break;
        case 32: _t->replaceCurrent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: { int _r = _t->replaceAll((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->pasteFromClipboard(); break;
        case 35: _t->slotMouseMovedWithControl((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 36: _t->slotMouseMovedWithControlReleased(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::documentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::textAreaChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::cursorPositionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::selectionStartChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::selectionEndChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::fontFamilyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::textColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::fontSizeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::textChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::fileUrlChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)(const QString & , int )>(_a, &DocumentHandler::loaded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)(const QString & )>(_a, &DocumentHandler::error, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::modifiedChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::searchMatchCountChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::searchCurrentMatchChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::focusUp, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::focusDown, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::copy, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::cut, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::undo, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)()>(_a, &DocumentHandler::redo, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)(int )>(_a, &DocumentHandler::moveCursor, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)(int , int )>(_a, &DocumentHandler::selectCursor, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentHandler::*)(const QString & )>(_a, &DocumentHandler::internalLinkActivated, 23))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickTextDocument* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickTextDocument**>(_v) = _t->document(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->textArea(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->cursorPosition(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->selectionStart(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->selectionEnd(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->fontFamily(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->fontSize(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->fileType(); break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->fileUrl(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->modified(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->searchMatchCount(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->searchCurrentMatch(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDocument(*reinterpret_cast<QQuickTextDocument**>(_v)); break;
        case 1: _t->setTextArea(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 2: _t->setCursorPosition(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSelectionStart(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setSelectionEnd(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setFontFamily(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setFontSize(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setModified(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DocumentHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DocumentHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DocumentHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DocumentHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 37;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void DocumentHandler::documentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DocumentHandler::textAreaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DocumentHandler::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DocumentHandler::selectionStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DocumentHandler::selectionEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DocumentHandler::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DocumentHandler::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DocumentHandler::fontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DocumentHandler::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DocumentHandler::fileUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DocumentHandler::loaded(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void DocumentHandler::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DocumentHandler::modifiedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DocumentHandler::searchMatchCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DocumentHandler::searchCurrentMatchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DocumentHandler::focusUp()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DocumentHandler::focusDown()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DocumentHandler::copy()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DocumentHandler::cut()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DocumentHandler::undo()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DocumentHandler::redo()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DocumentHandler::moveCursor(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void DocumentHandler::selectCursor(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1, _t2);
}

// SIGNAL 23
void DocumentHandler::internalLinkActivated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}
QT_WARNING_POP
