/****************************************************************************
** Meta object code from reading C++ file 'marknotesettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../marknotesettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'marknotesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Config::qt_create_metaobjectdata<qt_meta_tag_ZN6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Config",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "sortBehaviourChanged",
        "",
        "expandedSidebarChanged",
        "fillWindowChanged",
        "columnWidthChanged",
        "storageChanged",
        "colorSchemeChanged",
        "EditorFontChanged",
        "sortBehaviour",
        "isSortBehaviourImmutable",
        "defaultSortBehaviourValue",
        "expandedSidebar",
        "isExpandedSidebarImmutable",
        "defaultExpandedSidebarValue",
        "fillWindow",
        "isFillWindowImmutable",
        "defaultFillWindowValue",
        "columnWidth",
        "isColumnWidthImmutable",
        "defaultColumnWidthValue",
        "storage",
        "isStorageImmutable",
        "defaultStorageValue",
        "colorScheme",
        "isColorSchemeImmutable",
        "editorFont",
        "QFont",
        "isEditorFontImmutable",
        "defaultEditorFontValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sortBehaviourChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'expandedSidebarChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillWindowChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'columnWidthChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'storageChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EditorFontChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sortBehaviour'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSortBehaviourImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSortBehaviourValue'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'expandedSidebar'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isExpandedSidebarImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultExpandedSidebarValue'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fillWindow'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isFillWindowImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFillWindowValue'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'columnWidth'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isColumnWidthImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColumnWidthValue'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'storage'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isStorageImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStorageValue'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isColorSchemeImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'editorFont'
        QtMocHelpers::PropertyData<QFont>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'isEditorFontImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEditorFontValue'
        QtMocHelpers::PropertyData<QFont>(33, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Config, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Config::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ConfigE_t>.metaTypes,
    nullptr
} };

void Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sortBehaviourChanged(); break;
        case 1: _t->expandedSidebarChanged(); break;
        case 2: _t->fillWindowChanged(); break;
        case 3: _t->columnWidthChanged(); break;
        case 4: _t->storageChanged(); break;
        case 5: _t->colorSchemeChanged(); break;
        case 6: _t->EditorFontChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::sortBehaviourChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::expandedSidebarChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::fillWindowChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::columnWidthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::storageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::colorSchemeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::EditorFontChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->sortBehaviour(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSortBehaviourImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultSortBehaviourValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->expandedSidebar(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isExpandedSidebarImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultExpandedSidebarValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->fillWindow(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isFillWindowImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultFillWindowValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->columnWidth(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isColumnWidthImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultColumnWidthValue(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->storage(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isStorageImmutable(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->defaultStorageValue(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isColorSchemeImmutable(); break;
        case 17: *reinterpret_cast<QFont*>(_v) = _t->editorFont(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isEditorFontImmutable(); break;
        case 19: *reinterpret_cast<QFont*>(_v) = _t->defaultEditorFontValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSortBehaviour(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setExpandedSidebar(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setFillWindow(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setColumnWidth(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setStorage(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setColorScheme(*reinterpret_cast<QString*>(_v)); break;
        case 17: _t->setEditorFont(*reinterpret_cast<QFont*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Config::sortBehaviourChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Config::expandedSidebarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Config::fillWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Config::columnWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Config::storageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Config::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Config::EditorFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
