/****************************************************************************
** Meta object code from reading C++ file 'rich_documenthandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../marknote-1.5.2/src/rich_documenthandler.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rich_documenthandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19RichDocumentHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto RichDocumentHandler::qt_create_metaobjectdata<qt_meta_tag_ZN19RichDocumentHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RichDocumentHandler",
        "QML.Element",
        "auto",
        "alignmentChanged",
        "",
        "blockMarginChanged",
        "boldChanged",
        "italicChanged",
        "underlineChanged",
        "checkableChanged",
        "strikethroughChanged",
        "canPasteChanged",
        "showToast",
        "message",
        "load",
        "QUrl",
        "fileUrl",
        "saveAs",
        "indentListLess",
        "indentListMore",
        "setListStyle",
        "styleIndex",
        "setHeadingLevel",
        "level",
        "updateNoteLink",
        "noteName",
        "alias",
        "currentNoteLinkName",
        "currentNoteLinkAlias",
        "currentLinkUrl",
        "currentLinkText",
        "updateLink",
        "linkUrl",
        "linkText",
        "insertImage",
        "imagePath",
        "insertTable",
        "rows",
        "columns",
        "pasteFromClipboard",
        "slotKeyPressed",
        "key",
        "cursorPositionChanged",
        "fileUrlChanged",
        "modifiedChanged",
        "searchMatchCountChanged",
        "searchCurrentMatchChanged",
        "alignment",
        "Qt::Alignment",
        "bold",
        "italic",
        "underline",
        "strikethrough",
        "checkable",
        "canIndentList",
        "canDedentList",
        "currentListStyle",
        "currentHeadingLevel",
        "fileName",
        "fileType",
        "modified",
        "searchMatchCount",
        "searchCurrentMatch",
        "blockMargin",
        "canPaste"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'alignmentChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockMarginChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boldChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'italicChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'underlineChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkableChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'strikethroughChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPasteChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showToast'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QUrl &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void(const QUrl &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'indentListLess'
        QtMocHelpers::SlotData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'indentListMore'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setListStyle'
        QtMocHelpers::SlotData<void(int)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setHeadingLevel'
        QtMocHelpers::SlotData<void(int)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Method 'updateNoteLink'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::QString, 26 },
        }}),
        // Method 'updateNoteLink'
        QtMocHelpers::MethodData<void(const QString &)>(24, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'currentNoteLinkName'
        QtMocHelpers::MethodData<QString() const>(27, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'currentNoteLinkAlias'
        QtMocHelpers::MethodData<QString() const>(28, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'currentLinkUrl'
        QtMocHelpers::MethodData<QString() const>(29, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'currentLinkText'
        QtMocHelpers::MethodData<QString() const>(30, 4, QMC::AccessPublic, QMetaType::QString),
        // Method 'updateLink'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 33 },
        }}),
        // Method 'insertImage'
        QtMocHelpers::MethodData<void(const QUrl &)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 35 },
        }}),
        // Method 'insertTable'
        QtMocHelpers::MethodData<void(int, int)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 37 }, { QMetaType::Int, 38 },
        }}),
        // Method 'pasteFromClipboard'
        QtMocHelpers::MethodData<void()>(39, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'slotKeyPressed'
        QtMocHelpers::MethodData<void(int)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'alignment'
        QtMocHelpers::PropertyData<Qt::Alignment>(47, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'bold'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'italic'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'underline'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'strikethrough'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'checkable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'canIndentList'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags, 0x70000000 | 42),
        // property 'canDedentList'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags, 0x70000000 | 42),
        // property 'currentListStyle'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags, 0x70000000 | 42),
        // property 'currentHeadingLevel'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags, 0x70000000 | 42),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 0x70000000 | 43),
        // property 'fileType'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 0x70000000 | 43),
        // property 'fileUrl'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0x70000000 | 43),
        // property 'modified'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 44),
        // property 'searchMatchCount'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags, 0x70000000 | 45),
        // property 'searchCurrentMatch'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags, 0x70000000 | 46),
        // property 'blockMargin'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'canPaste'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RichDocumentHandler, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RichDocumentHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<DocumentHandler::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RichDocumentHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RichDocumentHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19RichDocumentHandlerE_t>.metaTypes,
    nullptr
} };

void RichDocumentHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RichDocumentHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->alignmentChanged(); break;
        case 1: _t->blockMarginChanged(); break;
        case 2: _t->boldChanged(); break;
        case 3: _t->italicChanged(); break;
        case 4: _t->underlineChanged(); break;
        case 5: _t->checkableChanged(); break;
        case 6: _t->strikethroughChanged(); break;
        case 7: _t->canPasteChanged(); break;
        case 8: _t->showToast((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->load((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->indentListLess(); break;
        case 12: _t->indentListMore(); break;
        case 13: _t->setListStyle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setHeadingLevel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->updateNoteLink((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->updateNoteLink((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: { QString _r = _t->currentNoteLinkName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->currentNoteLinkAlias();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->currentLinkUrl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->currentLinkText();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->updateLink((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->insertImage((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 23: _t->insertTable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->pasteFromClipboard(); break;
        case 25: _t->slotKeyPressed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::alignmentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::blockMarginChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::boldChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::italicChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::underlineChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::checkableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::strikethroughChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)()>(_a, &RichDocumentHandler::canPasteChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RichDocumentHandler::*)(const QString & )>(_a, &RichDocumentHandler::showToast, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Qt::Alignment*>(_v) = _t->alignment(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->bold(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->italic(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->underline(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->strikethrough(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->checkable(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->canIndentList(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->canDedentList(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->currentListStyle(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->currentHeadingLevel(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->fileType(); break;
        case 12: *reinterpret_cast<QUrl*>(_v) = _t->fileUrl(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->modified(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->searchMatchCount(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->searchCurrentMatch(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->blockMargin(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->canPaste(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAlignment(*reinterpret_cast<Qt::Alignment*>(_v)); break;
        case 1: _t->setBold(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setItalic(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setUnderline(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setStrikethrough(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setCheckable(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setModified(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setBlockMargin(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *RichDocumentHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RichDocumentHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RichDocumentHandlerE_t>.strings))
        return static_cast<void*>(this);
    return DocumentHandler::qt_metacast(_clname);
}

int RichDocumentHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DocumentHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void RichDocumentHandler::alignmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RichDocumentHandler::blockMarginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RichDocumentHandler::boldChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RichDocumentHandler::italicChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void RichDocumentHandler::underlineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void RichDocumentHandler::checkableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void RichDocumentHandler::strikethroughChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void RichDocumentHandler::canPasteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void RichDocumentHandler::showToast(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
namespace CheckNotifySignalValidity_ZN19RichDocumentHandlerE {
template<typename T> using has_nullary_cursorPositionChanged = decltype(std::declval<T>().cursorPositionChanged());
template<typename T> using has_unary_cursorPositionChanged = decltype(std::declval<T>().cursorPositionChanged(std::declval<bool>()));
static_assert(qxp::is_detected_v<has_nullary_cursorPositionChanged, RichDocumentHandler> || qxp::is_detected_v<has_unary_cursorPositionChanged, RichDocumentHandler>,
              "NOTIFY signal cursorPositionChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_fileUrlChanged = decltype(std::declval<T>().fileUrlChanged());
template<typename T> using has_unary_fileUrlChanged = decltype(std::declval<T>().fileUrlChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_fileUrlChanged, RichDocumentHandler> || qxp::is_detected_v<has_unary_fileUrlChanged, RichDocumentHandler>,
              "NOTIFY signal fileUrlChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_modifiedChanged = decltype(std::declval<T>().modifiedChanged());
template<typename T> using has_unary_modifiedChanged = decltype(std::declval<T>().modifiedChanged(std::declval<bool>()));
static_assert(qxp::is_detected_v<has_nullary_modifiedChanged, RichDocumentHandler> || qxp::is_detected_v<has_unary_modifiedChanged, RichDocumentHandler>,
              "NOTIFY signal modifiedChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_searchMatchCountChanged = decltype(std::declval<T>().searchMatchCountChanged());
template<typename T> using has_unary_searchMatchCountChanged = decltype(std::declval<T>().searchMatchCountChanged(std::declval<int>()));
static_assert(qxp::is_detected_v<has_nullary_searchMatchCountChanged, RichDocumentHandler> || qxp::is_detected_v<has_unary_searchMatchCountChanged, RichDocumentHandler>,
              "NOTIFY signal searchMatchCountChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_searchCurrentMatchChanged = decltype(std::declval<T>().searchCurrentMatchChanged());
template<typename T> using has_unary_searchCurrentMatchChanged = decltype(std::declval<T>().searchCurrentMatchChanged(std::declval<int>()));
static_assert(qxp::is_detected_v<has_nullary_searchCurrentMatchChanged, RichDocumentHandler> || qxp::is_detected_v<has_unary_searchCurrentMatchChanged, RichDocumentHandler>,
              "NOTIFY signal searchCurrentMatchChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
