/****************************************************************************
** Meta object code from reading C++ file 'tableactionhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../marknote-1.5.2/src/tableactionhelper.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tableactionhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17TableActionHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto TableActionHelper::qt_create_metaobjectdata<qt_meta_tag_ZN17TableActionHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TableActionHelper",
        "QML.Element",
        "auto",
        "cursorPositionChanged",
        "",
        "documentChanged",
        "selectionStartChanged",
        "selectionEndChanged",
        "document",
        "QQuickTextDocument*",
        "cursorPosition",
        "selectionStart",
        "selectionEnd",
        "actionInsertRowBelow",
        "QAction*",
        "actionInsertRowAbove",
        "actionInsertColumnBefore",
        "actionInsertColumnAfter",
        "actionRemoveRow",
        "actionRemoveColumn",
        "actionRemoveCellContents"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cursorPositionChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionStartChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionEndChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'document'
        QtMocHelpers::PropertyData<QQuickTextDocument*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'cursorPosition'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'selectionStart'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'selectionEnd'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'actionInsertRowBelow'
        QtMocHelpers::PropertyData<QAction*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actionInsertRowAbove'
        QtMocHelpers::PropertyData<QAction*>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actionInsertColumnBefore'
        QtMocHelpers::PropertyData<QAction*>(16, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actionInsertColumnAfter'
        QtMocHelpers::PropertyData<QAction*>(17, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actionRemoveRow'
        QtMocHelpers::PropertyData<QAction*>(18, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actionRemoveColumn'
        QtMocHelpers::PropertyData<QAction*>(19, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'actionRemoveCellContents'
        QtMocHelpers::PropertyData<QAction*>(20, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TableActionHelper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TableActionHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TableActionHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TableActionHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TableActionHelperE_t>.metaTypes,
    nullptr
} };

void TableActionHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TableActionHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cursorPositionChanged(); break;
        case 1: _t->documentChanged(); break;
        case 2: _t->selectionStartChanged(); break;
        case 3: _t->selectionEndChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TableActionHelper::*)()>(_a, &TableActionHelper::cursorPositionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TableActionHelper::*)()>(_a, &TableActionHelper::documentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TableActionHelper::*)()>(_a, &TableActionHelper::selectionStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TableActionHelper::*)()>(_a, &TableActionHelper::selectionEndChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
        case 9:
        case 8:
        case 7:
        case 6:
        case 5:
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickTextDocument* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuickTextDocument**>(_v) = _t->document(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->cursorPosition(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->selectionStart(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->selectionEnd(); break;
        case 4: *reinterpret_cast<QAction**>(_v) = _t->actionInsertRowBelow; break;
        case 5: *reinterpret_cast<QAction**>(_v) = _t->actionInsertRowAbove; break;
        case 6: *reinterpret_cast<QAction**>(_v) = _t->actionInsertColumnBefore; break;
        case 7: *reinterpret_cast<QAction**>(_v) = _t->actionInsertColumnAfter; break;
        case 8: *reinterpret_cast<QAction**>(_v) = _t->actionRemoveRow; break;
        case 9: *reinterpret_cast<QAction**>(_v) = _t->actionRemoveColumn; break;
        case 10: *reinterpret_cast<QAction**>(_v) = _t->actionRemoveCellContents; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDocument(*reinterpret_cast<QQuickTextDocument**>(_v)); break;
        case 1: _t->setCursorPosition(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setSelectionStart(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSelectionEnd(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TableActionHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TableActionHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TableActionHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TableActionHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void TableActionHelper::cursorPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TableActionHelper::documentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TableActionHelper::selectionStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TableActionHelper::selectionEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
