/****************************************************************************
** Meta object code from reading C++ file 'raw_documenthandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../marknote-1.5.2/src/raw_documenthandler.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'raw_documenthandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18RawDocumentHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto RawDocumentHandler::qt_create_metaobjectdata<qt_meta_tag_ZN18RawDocumentHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RawDocumentHandler",
        "QML.Element",
        "auto",
        "load",
        "",
        "QUrl",
        "fileUrl",
        "saveAs",
        "pasteFromClipboard",
        "fileUrlChanged",
        "modifiedChanged",
        "fileName",
        "fileType",
        "modified"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'load'
        QtMocHelpers::SlotData<void(const QUrl &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void(const QUrl &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Method 'pasteFromClipboard'
        QtMocHelpers::MethodData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 0x70000000 | 9),
        // property 'fileType'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 0x70000000 | 9),
        // property 'fileUrl'
        QtMocHelpers::PropertyData<QUrl>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0x70000000 | 9),
        // property 'modified'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 10),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RawDocumentHandler, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RawDocumentHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<DocumentHandler::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18RawDocumentHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18RawDocumentHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18RawDocumentHandlerE_t>.metaTypes,
    nullptr
} };

void RawDocumentHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RawDocumentHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->load((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->pasteFromClipboard(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fileType(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->fileUrl(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->modified(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setModified(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *RawDocumentHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RawDocumentHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18RawDocumentHandlerE_t>.strings))
        return static_cast<void*>(this);
    return DocumentHandler::qt_metacast(_clname);
}

int RawDocumentHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DocumentHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace CheckNotifySignalValidity_ZN18RawDocumentHandlerE {
template<typename T> using has_nullary_fileUrlChanged = decltype(std::declval<T>().fileUrlChanged());
template<typename T> using has_unary_fileUrlChanged = decltype(std::declval<T>().fileUrlChanged(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_fileUrlChanged, RawDocumentHandler> || qxp::is_detected_v<has_unary_fileUrlChanged, RawDocumentHandler>,
              "NOTIFY signal fileUrlChanged does not exist in class (or is private in its parent)");
template<typename T> using has_nullary_modifiedChanged = decltype(std::declval<T>().modifiedChanged());
template<typename T> using has_unary_modifiedChanged = decltype(std::declval<T>().modifiedChanged(std::declval<bool>()));
static_assert(qxp::is_detected_v<has_nullary_modifiedChanged, RawDocumentHandler> || qxp::is_detected_v<has_unary_modifiedChanged, RawDocumentHandler>,
              "NOTIFY signal modifiedChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
