// /qt/qml/org/kde/marknote/qml/NotebookDeleteDialog.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_marknote_qml_NotebookDeleteDialog_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x94,0xe,0x0,0x0,0x54,0x4d,0x2a,0x6f,
0xb,0x4,0xc9,0x2b,0xe2,0x23,0xf5,0x88,
0x45,0x17,0x9,0xd1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x2e,0x0,0x0,0x0,0xd0,0x4,0x0,0x0,
0x9,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0xc,0x0,0x0,
0x70,0x1,0x0,0x0,0xc8,0x1,0x0,0x0,
0x28,0x2,0x0,0x0,0x88,0x2,0x0,0x0,
0xe8,0x2,0x0,0x0,0x48,0x3,0x0,0x0,
0xc0,0x3,0x0,0x0,0x10,0x4,0x0,0x0,
0x60,0x4,0x0,0x0,0xb0,0x4,0x0,0x0,
0xc0,0x4,0x0,0x0,0x43,0x0,0x0,0x0,
0xf0,0x1,0x0,0x0,0x0,0x2,0x0,0x0,
0x13,0x2,0x0,0x0,0x24,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0x54,0x2,0x0,0x0,
0xf3,0x0,0x0,0x0,0x64,0x2,0x0,0x0,
0x23,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x80,0x2,0x0,0x0,0x23,0x0,0x0,0x0,
0x70,0x2,0x0,0x0,0x90,0x2,0x0,0x0,
0x13,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0xc0,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0xb0,0x0,0x0,0x0,
0xa4,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x3c,0x2,0x18,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x1a,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x18,0x7,
0x12,0x23,0x18,0xa,0x12,0x24,0x18,0xb,
0xac,0x4,0x7,0x2,0xa,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0x5,0x18,0x7,0xac,0x6,0x7,
0x0,0x0,0x18,0x6,0xd4,0x16,0x6,0x2,
0x50,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1c,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0x7,0x18,0x7,0xac,0x8,0x7,
0x0,0x0,0x18,0x6,0xd4,0x16,0x6,0x2,
0x44,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x1d,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x9,0x3c,0xa,
0x3c,0xb,0x18,0x7,0x2e,0xc,0x3c,0xd,
0x3c,0xe,0x84,0x7,0x18,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x2c,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xf,0x0,0x0,0x0,
0x1f,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1f,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xf,0x18,0x7,
0x12,0x2b,0x18,0xa,0x2e,0x10,0x3c,0x11,
0x18,0xb,0x2e,0x12,0x3c,0x13,0x3c,0x14,
0x18,0xd,0x12,0x2d,0x80,0xd,0x18,0xe,
0x2e,0x15,0x3c,0x16,0x80,0xe,0x18,0xc,
0xac,0x17,0x7,0x3,0xa,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x15,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x18,0x3c,0x19,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1a,0x3c,0x1b,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x17,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1c,0x3c,0x1d,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x88,0x5,0x0,0x0,0x90,0x5,0x0,0x0,
0xa8,0x5,0x0,0x0,0xc0,0x5,0x0,0x0,
0xe8,0x5,0x0,0x0,0x8,0x6,0x0,0x0,
0x50,0x6,0x0,0x0,0x78,0x6,0x0,0x0,
0x98,0x6,0x0,0x0,0xd0,0x6,0x0,0x0,
0xf0,0x6,0x0,0x0,0x0,0x7,0x0,0x0,
0x10,0x7,0x0,0x0,0x38,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x78,0x7,0x0,0x0,
0x98,0x7,0x0,0x0,0xc8,0x7,0x0,0x0,
0xf8,0x7,0x0,0x0,0x28,0x8,0x0,0x0,
0x48,0x8,0x0,0x0,0x80,0x8,0x0,0x0,
0x90,0x8,0x0,0x0,0xc0,0x8,0x0,0x0,
0xe0,0x8,0x0,0x0,0x18,0x9,0x0,0x0,
0x38,0x9,0x0,0x0,0x70,0x9,0x0,0x0,
0x98,0x9,0x0,0x0,0xe0,0x9,0x0,0x0,
0xf8,0x9,0x0,0x0,0x30,0xa,0x0,0x0,
0x50,0xa,0x0,0x0,0x68,0xa,0x0,0x0,
0x78,0xa,0x0,0x0,0x88,0xa,0x0,0x0,
0xa8,0xa,0x0,0x0,0xd0,0xa,0x0,0x0,
0xe0,0xa,0x0,0x0,0xf8,0xa,0x0,0x0,
0x10,0xb,0x0,0x0,0x20,0xb,0x0,0x0,
0x38,0xb,0x0,0x0,0x48,0xb,0x0,0x0,
0x30,0xc,0x0,0x0,0x50,0xc,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x43,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,
0x2e,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,
0x70,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6d,0x0,0x61,0x0,
0x72,0x0,0x6b,0x0,0x6e,0x0,0x6f,0x0,
0x74,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x31,0x0,0x38,0x0,0x6e,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x73,0x0,
0x2e,0x0,0x4d,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x61,0x0,0x67,0x0,0x65,0x0,
0x44,0x0,0x69,0x0,0x61,0x0,0x6c,0x0,
0x6f,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x6d,0x0,0x6f,0x0,0x76,0x0,0x65,0x0,
0x44,0x0,0x69,0x0,0x61,0x0,0x6c,0x0,
0x6f,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x6e,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x4e,0x0,0x6f,0x0,
0x74,0x0,0x65,0x0,0x42,0x0,0x6f,0x0,
0x6f,0x0,0x6b,0x0,0x73,0x0,0x4d,0x0,
0x6f,0x0,0x64,0x0,0x65,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x64,0x0,0x65,0x0,0x6c,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x4e,0x0,0x6f,0x0,
0x74,0x0,0x65,0x0,0x62,0x0,0x6f,0x0,
0x6f,0x0,0x6b,0x0,0x44,0x0,0x65,0x0,
0x6c,0x0,0x65,0x0,0x74,0x0,0x65,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x6c,0x0,0x65,0x0,0x74,0x0,0x65,0x0,
0x41,0x0,0x63,0x0,0x74,0x0,0x69,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6e,0x0,0x61,0x0,0x6d,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x61,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6d,0x0,0x6f,0x0,0x64,0x0,
0x65,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x64,0x0,0x69,0x0,
0x61,0x0,0x6c,0x0,0x6f,0x0,0x67,0x0,
0x54,0x0,0x79,0x0,0x70,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x64,0x0,0x69,0x0,0x61,0x0,
0x6c,0x0,0x6f,0x0,0x67,0x0,0x54,0x0,
0x79,0x0,0x70,0x0,0x65,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x74,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x69,0x0,0x74,0x0,
0x6c,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x52,0x0,0x65,0x0,0x6a,0x0,0x65,0x0,
0x63,0x0,0x74,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x52,0x0,
0x65,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,
0x74,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x41,0x0,0x63,0x0,0x63,0x0,0x65,0x0,
0x70,0x0,0x74,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x41,0x0,
0x63,0x0,0x63,0x0,0x65,0x0,0x70,0x0,
0x74,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x61,0x0,0x6e,0x0,0x64,0x0,0x61,0x0,
0x72,0x0,0x64,0x0,0x42,0x0,0x75,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6e,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x74,0x0,0x61,0x0,
0x6e,0x0,0x64,0x0,0x61,0x0,0x72,0x0,
0x64,0x0,0x42,0x0,0x75,0x0,0x74,0x0,
0x74,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x73,0x0,0x75,0x0,
0x62,0x0,0x74,0x0,0x69,0x0,0x74,0x0,
0x6c,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x75,0x0,0x62,0x0,
0x74,0x0,0x69,0x0,0x74,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x4d,0x0,0x65,0x0,
0x73,0x0,0x73,0x0,0x61,0x0,0x67,0x0,
0x65,0x0,0x44,0x0,0x69,0x0,0x61,0x0,
0x6c,0x0,0x6f,0x0,0x67,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x57,0x0,0x61,0x0,
0x72,0x0,0x6e,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x4b,0x0,0x49,0x0,
0x31,0x0,0x38,0x0,0x6e,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x69,0x0,0x31,0x0,
0x38,0x0,0x6e,0x0,0x63,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x40,0x0,0x74,0x0,
0x69,0x0,0x74,0x0,0x6c,0x0,0x65,0x0,
0x3a,0x0,0x77,0x0,0x69,0x0,0x6e,0x0,
0x64,0x0,0x6f,0x0,0x77,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x44,0x0,0x65,0x0,
0x6c,0x0,0x65,0x0,0x74,0x0,0x65,0x0,
0x20,0x0,0x4e,0x0,0x6f,0x0,0x74,0x0,
0x65,0x0,0x62,0x0,0x6f,0x0,0x6f,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6c,0x0,
0x6f,0x0,0x73,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x74,0x0,0x72,0x0,
0x69,0x0,0x67,0x0,0x67,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x44,0x0,0x69,0x0,
0x61,0x0,0x6c,0x0,0x6f,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4f,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x43,0x0,0x61,0x0,
0x6e,0x0,0x63,0x0,0x65,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x69,0x0,0x31,0x0,
0x38,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x6f,0x0,0x0,0x0,0x41,0x0,0x72,0x0,
0x65,0x0,0x20,0x0,0x79,0x0,0x6f,0x0,
0x75,0x0,0x20,0x0,0x73,0x0,0x75,0x0,
0x72,0x0,0x65,0x0,0x20,0x0,0x79,0x0,
0x6f,0x0,0x75,0x0,0x20,0x0,0x77,0x0,
0x61,0x0,0x6e,0x0,0x74,0x0,0x20,0x0,
0x74,0x0,0x6f,0x0,0x20,0x0,0x64,0x0,
0x65,0x0,0x6c,0x0,0x65,0x0,0x74,0x0,
0x65,0x0,0x20,0x0,0x74,0x0,0x68,0x0,
0x65,0x0,0x20,0x0,0x4e,0x0,0x6f,0x0,
0x74,0x0,0x65,0x0,0x62,0x0,0x6f,0x0,
0x6f,0x0,0x6b,0x0,0x20,0x0,0x3c,0x0,
0x62,0x0,0x3e,0x0,0x25,0x0,0x31,0x0,
0x3c,0x0,0x2f,0x0,0x62,0x0,0x3e,0x0,
0x3f,0x0,0x20,0x0,0x54,0x0,0x68,0x0,
0x69,0x0,0x73,0x0,0x20,0x0,0x77,0x0,
0x69,0x0,0x6c,0x0,0x6c,0x0,0x20,0x0,
0x64,0x0,0x65,0x0,0x6c,0x0,0x65,0x0,
0x74,0x0,0x65,0x0,0x20,0x0,0x74,0x0,
0x68,0x0,0x65,0x0,0x20,0x0,0x63,0x0,
0x6f,0x0,0x6e,0x0,0x74,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x20,0x0,0x6f,0x0,
0x66,0x0,0x20,0x0,0x3c,0x0,0x62,0x0,
0x3e,0x0,0x25,0x0,0x32,0x0,0x3c,0x0,
0x2f,0x0,0x62,0x0,0x3e,0x0,0x20,0x0,
0x64,0x0,0x65,0x0,0x66,0x0,0x69,0x0,
0x6e,0x0,0x69,0x0,0x74,0x0,0x69,0x0,
0x76,0x0,0x65,0x0,0x6c,0x0,0x79,0x0,
0x2e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x6f,0x0,0x72,0x0,0x61,0x0,0x67,0x0,
0x65,0x0,0x50,0x0,0x61,0x0,0x74,0x0,
0x68,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2f,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x74,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x7,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x7c,0x0,0x0,0x0,
0x9c,0x1,0x0,0x0,0x8,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x3,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x78,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x78,0x0,0x0,0x0,0x78,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x78,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0xd,0x0,0x10,0x0,0xe,0x0,0x50,0x0,
0x20,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x20,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x5,0x0,0x0,0x20,
0x10,0x0,0x50,0x0,0xb,0x0,0x0,0x0,
0x5,0x0,0x0,0x20,0x11,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x1d,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1f,0x0,0x50,0x0,
0x1f,0x0,0xf0,0x0,0x1b,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x50,0x0,
0x1d,0x0,0x60,0x1,0x19,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x50,0x0,
0x1c,0x0,0x10,0x1,0x17,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x50,0x0,
0x1b,0x0,0x10,0x1,0x15,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x50,0x0,
0x1a,0x0,0xc0,0x0,0x13,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x50,0x0,
0x19,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x50,0x0,
0x13,0x0,0x50,0x0,0xe,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x3,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9c,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0x14,0x0,0x90,0x0,
0x9c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x90,0x0,0x17,0x0,0x0,0x1,
0xa,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x7,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x16,0x0,0xf0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x90,0x0,0x15,0x0,0xf0,0x0,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<int>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for dialogType at line 25, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_GetLookup
s.v2_4 = 1;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<int *>(argv[0]) = s.v2_4;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for title at line 26, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_12;
QVariant v2_4;
QVariant v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(3, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(3, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QVariant::fromValue(QStringLiteral("@title:window"));
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_8 = QVariant::fromValue(QStringLiteral("Delete Notebook"));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant retrieved;
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_4, &s.v2_8};
    return aotContext->callObjectPropertyLookup(4, s.v2_0, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(4, s.v2_0);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
retrieved = std::move(callResult);
aotContext->setImplicitDestructible(retrieved);
}
s.v2_12 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_12);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onRejected at line 27, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(5, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const auto doCall = [&]() {
    void *args[] = {nullptr};
    return aotContext->callObjectPropertyLookup(6, s.v2_1, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(6, s.v2_1, 61);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for subtitle at line 31, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_14, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_28, markStack);
    aotContext->mark(v2_32, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_14 = nullptr;
QObject *v2_16 = nullptr;
QObject *v2_28 = nullptr;
QObject *v2_8 = nullptr;
QString v2_18;
QString v2_22;
QString v2_24;
QString v2_30;
QString v2_36;
QVariant v2_10;
QVariant v2_32;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(15, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(15, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QVariant::fromValue(QStringLiteral("Are you sure you want to delete the Notebook <b>%1</b>\? This will delete the content of <b>%2</b> definitively."));
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->loadContextIdLookup(16, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initLoadContextIdLookup(16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
{
QString retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->getObjectLookup(17, s.v2_8, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initGetObjectLookup(17, s.v2_8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
s.v2_10 = QVariant::fromValue(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
while (!aotContext->loadContextIdLookup(18, &s.v2_14)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(16);
#endif
aotContext->initLoadContextIdLookup(18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getObjectLookup(19, s.v2_14, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetObjectLookup(19, s.v2_14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getObjectLookup(20, s.v2_16, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetObjectLookupAsVariant(20, s.v2_16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
s.v2_18 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_22 = QStringLiteral("/");
{
}
// generate_Add
s.v2_24 = QString(std::move(s.v2_18) + std::move(s.v2_22));
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(30);
#endif
while (!aotContext->loadContextIdLookup(21, &s.v2_28)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(30);
#endif
aotContext->initLoadContextIdLookup(21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
while (!aotContext->getObjectLookup(22, s.v2_28, &s.v2_30)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(32);
#endif
aotContext->initGetObjectLookup(22, s.v2_28);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_Add
s.v2_32 = QVariant::fromValue(QString(std::move(s.v2_24) + std::move(s.v2_30)));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant retrieved;
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_4, &s.v2_10, &s.v2_32};
    return aotContext->callObjectPropertyLookup(23, s.v2_0, args, 3);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(23, s.v2_0);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(41);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(41);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
retrieved = std::move(callResult);
aotContext->setImplicitDestructible(retrieved);
}
s.v2_36 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_36);
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for name at line 21, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(24, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(24);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(25, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(25, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_2);
}
return;
}
 },{ 7, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for path at line 22, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(26, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(26);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(27, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(27, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_2);
}
return;
}
 },{ 8, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("NoteBooksModel*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for model at line 23, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_2 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(28, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(28);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(29, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(29, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
