/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<application.h>)
#  include <application.h>
#endif
#if __has_include(<colorschemer.h>)
#  include <colorschemer.h>
#endif
#if __has_include(<documenthandler.h>)
#  include <documenthandler.h>
#endif
#if __has_include(<maildirimport.h>)
#  include <maildirimport.h>
#endif
#if __has_include(<marknotesettings.h>)
#  include <marknotesettings.h>
#endif
#if __has_include(<navigationcontroller.h>)
#  include <navigationcontroller.h>
#endif
#if __has_include(<notebooksmodel.h>)
#  include <notebooksmodel.h>
#endif
#if __has_include(<notesmodel.h>)
#  include <notesmodel.h>
#endif
#if __has_include(<raw_documenthandler.h>)
#  include <raw_documenthandler.h>
#endif
#if __has_include(<rich_documenthandler.h>)
#  include <rich_documenthandler.h>
#endif
#if __has_include(<sketchhistory.h>)
#  include <sketchhistory.h>
#endif
#if __has_include(<tableactionhelper.h>)
#  include <tableactionhelper.h>
#endif
#if __has_include(<tocmodel.h>)
#  include <tocmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_marknote()
{
    qmlRegisterModule("org.kde.marknote", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<App>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<ColorSchemer>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<Config>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<DocumentHandler>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<HistoryController>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<MaildirImport>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<NavigationController>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<NoteBooksModel>("org.kde.marknote", 254);
    qmlRegisterEnum<NoteBooksModel::Role>("NoteBooksModel::Role");
    qmlRegisterTypesAndRevisions<NotesModel>("org.kde.marknote", 254);
    qmlRegisterEnum<NotesModel::Role>("NotesModel::Role");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<RawDocumentHandler>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<RichDocumentHandler>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<TableActionHelper>("org.kde.marknote", 254);
    qmlRegisterTypesAndRevisions<TocModel>("org.kde.marknote", 254);
    qmlRegisterEnum<TocModel::Role>("TocModel::Role");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.marknote", 254, 254);
}

static const QQmlModuleRegistration orgkdemarknoteRegistration("org.kde.marknote", qml_register_types_org_kde_marknote);
