// /qt/qml/org/kde/marknote/qml/NativeWindowMenu.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_marknote_qml_NativeWindowMenu_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd8,0xc,0x0,0x0,0x2,0x4e,0x47,0xec,
0x11,0x65,0xf0,0x63,0x9b,0x49,0x37,0x40,
0x34,0x48,0xf2,0xea,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x29,0x0,0x0,0x0,0xd0,0x3,0x0,0x0,
0x5,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe8,0x9,0x0,0x0,
0x60,0x1,0x0,0x0,0xc0,0x1,0x0,0x0,
0x10,0x2,0x0,0x0,0xb0,0x2,0x0,0x0,
0x0,0x3,0x0,0x0,0xc0,0x3,0x0,0x0,
0xe3,0x1,0x0,0x0,0xf4,0x1,0x0,0x0,
0x13,0x2,0x0,0x0,0xa3,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0xa3,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x20,0x2,0x0,0x0,
0xb3,0x0,0x0,0x0,0x30,0x2,0x0,0x0,
0xe3,0x1,0x0,0x0,0xf4,0x1,0x0,0x0,
0xe3,0x1,0x0,0x0,0xf4,0x1,0x0,0x0,
0x63,0x2,0x0,0x0,0x30,0x2,0x0,0x0,
0xa3,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0xa3,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0x20,0x2,0x0,0x0,0xb3,0x0,0x0,0x0,
0x30,0x2,0x0,0x0,0xa3,0x0,0x0,0x0,
0xc0,0x0,0x0,0x0,0x74,0x2,0x0,0x0,
0xa3,0x0,0x0,0x0,0xc0,0x0,0x0,0x0,
0x84,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x18,0x7,
0x12,0x20,0x18,0xa,0x12,0xb,0x18,0xb,
0xac,0x1,0x7,0x2,0xa,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x16,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x3d,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x29,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x3,0x3c,0x4,
0x50,0x23,0x2e,0x5,0x3c,0x6,0x3c,0x7,
0x18,0x7,0x2e,0x8,0x3c,0x9,0x6c,0x7,
0x50,0x13,0x2e,0xa,0x18,0x8,0x12,0x20,
0x18,0xb,0x12,0x24,0x18,0xc,0xac,0xb,
0x8,0x2,0xb,0x4c,0x11,0x2e,0xc,0x18,
0x8,0x12,0x20,0x18,0xb,0x12,0x25,0x18,
0xc,0xac,0xd,0x8,0x2,0xb,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1e,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xe,0x3c,0xf,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0xb,0x0,0x0,0x0,
0x20,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x22,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x23,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x26,0x0,0x0,0x0,0x25,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x28,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xca,0x2e,0x10,0x3c,0x11,0x50,0x2c,0x2e,
0x12,0x3c,0x13,0x3c,0x14,0x18,0x7,0x2e,
0x15,0x3c,0x16,0x6c,0x7,0x50,0xf,0x2e,
0x17,0x3c,0x18,0x18,0x8,0xac,0x19,0x8,
0x0,0x0,0x18,0x6,0x4c,0xd,0x2e,0x1a,
0x3c,0x1b,0x18,0x8,0xac,0x1c,0x8,0x0,
0x0,0x18,0x6,0xd4,0x16,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x78,0x4,0x0,0x0,0x80,0x4,0x0,0x0,
0x98,0x4,0x0,0x0,0xc0,0x4,0x0,0x0,
0xd0,0x4,0x0,0x0,0xf8,0x4,0x0,0x0,
0x20,0x5,0x0,0x0,0x78,0x5,0x0,0x0,
0xa0,0x5,0x0,0x0,0xc0,0x5,0x0,0x0,
0xd8,0x5,0x0,0x0,0xe8,0x5,0x0,0x0,
0x0,0x6,0x0,0x0,0x18,0x6,0x0,0x0,
0x28,0x6,0x0,0x0,0x58,0x6,0x0,0x0,
0xa0,0x6,0x0,0x0,0xc0,0x6,0x0,0x0,
0xe8,0x6,0x0,0x0,0x8,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x68,0x7,0x0,0x0,
0x78,0x7,0x0,0x0,0xa8,0x7,0x0,0x0,
0xb8,0x7,0x0,0x0,0xc8,0x7,0x0,0x0,
0xf0,0x7,0x0,0x0,0x8,0x8,0x0,0x0,
0x40,0x8,0x0,0x0,0x60,0x8,0x0,0x0,
0xa0,0x8,0x0,0x0,0xb0,0x8,0x0,0x0,
0xc0,0x8,0x0,0x0,0xe0,0x8,0x0,0x0,
0xf0,0x8,0x0,0x0,0x10,0x9,0x0,0x0,
0x30,0x9,0x0,0x0,0x58,0x9,0x0,0x0,
0x80,0x9,0x0,0x0,0xa0,0x9,0x0,0x0,
0xc0,0x9,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x57,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4c,0x0,0x61,0x0,
0x62,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x2e,0x0,0x6c,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x74,0x0,0x66,0x0,0x6f,0x0,
0x72,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x61,0x0,0x74,0x0,0x65,0x0,0x66,0x0,
0x75,0x0,0x6c,0x0,0x41,0x0,0x70,0x0,
0x70,0x0,0x4c,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x27,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x61,0x0,
0x6d,0x0,0x69,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,
0x2e,0x0,0x73,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x66,0x0,0x75,0x0,
0x6c,0x0,0x61,0x0,0x70,0x0,0x70,0x0,
0x2e,0x0,0x6c,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6d,0x0,0x61,0x0,
0x72,0x0,0x6b,0x0,0x6e,0x0,0x6f,0x0,
0x74,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x69,0x0,
0x31,0x0,0x38,0x0,0x6e,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x4c,0x0,0x61,0x0,
0x62,0x0,0x73,0x0,0x2e,0x0,0x4d,0x0,
0x65,0x0,0x6e,0x0,0x75,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x57,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x5f,0x0,0x77,0x0,
0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,
0x77,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x74,0x0,0x69,0x0,
0x74,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x69,0x0,0x74,0x0,
0x6c,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x61,0x0,0x74,0x0,0x65,0x0,0x66,0x0,
0x75,0x0,0x6c,0x0,0x41,0x0,0x70,0x0,
0x70,0x0,0x4c,0x0,0x61,0x0,0x62,0x0,
0x73,0x0,0x2e,0x0,0x4e,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x76,0x0,0x65,0x0,
0x4d,0x0,0x65,0x0,0x6e,0x0,0x75,0x0,
0x49,0x0,0x74,0x0,0x65,0x0,0x6d,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x4e,0x0,0x61,0x0,0x6d,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x6f,0x0,0x70,0x0,
0x65,0x0,0x6e,0x0,0x5f,0x0,0x6b,0x0,
0x63,0x0,0x6f,0x0,0x6d,0x0,0x6d,0x0,
0x61,0x0,0x6e,0x0,0x64,0x0,0x5f,0x0,
0x62,0x0,0x61,0x0,0x72,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x61,0x0,0x70,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x61,0x0,0x70,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x4c,0x0,0x61,0x0,
0x62,0x0,0x73,0x0,0x2e,0x0,0x4d,0x0,
0x65,0x0,0x6e,0x0,0x75,0x0,0x49,0x0,
0x74,0x0,0x65,0x0,0x6d,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x65,0x0,0x78,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x69,0x0,0x63,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x6e,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x65,0x0,0x77,0x0,0x2d,0x0,0x66,0x0,
0x75,0x0,0x6c,0x0,0x6c,0x0,0x73,0x0,
0x63,0x0,0x72,0x0,0x65,0x0,0x65,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x73,0x0,0x68,0x0,
0x6f,0x0,0x72,0x0,0x74,0x0,0x63,0x0,
0x75,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x68,0x0,0x6f,0x0,
0x72,0x0,0x74,0x0,0x63,0x0,0x75,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x54,0x0,0x72,0x0,0x69,0x0,0x67,0x0,
0x67,0x0,0x65,0x0,0x72,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x54,0x0,
0x72,0x0,0x69,0x0,0x67,0x0,0x67,0x0,
0x65,0x0,0x72,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x4b,0x0,0x49,0x0,
0x31,0x0,0x38,0x0,0x6e,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x69,0x0,0x31,0x0,
0x38,0x0,0x6e,0x0,0x63,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x40,0x0,0x61,0x0,
0x63,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,
0x6e,0x0,0x3a,0x0,0x6d,0x0,0x65,0x0,
0x6e,0x0,0x75,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x41,0x0,0x70,0x0,
0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x73,0x0,0x69,0x0,0x62,0x0,0x69,0x0,
0x6c,0x0,0x69,0x0,0x74,0x0,0x79,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x46,0x0,0x75,0x0,
0x6c,0x0,0x6c,0x0,0x53,0x0,0x63,0x0,
0x72,0x0,0x65,0x0,0x65,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x45,0x0,0x78,0x0,
0x69,0x0,0x74,0x0,0x20,0x0,0x46,0x0,
0x75,0x0,0x6c,0x0,0x6c,0x0,0x20,0x0,
0x53,0x0,0x63,0x0,0x72,0x0,0x65,0x0,
0x65,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x45,0x0,0x6e,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x20,0x0,
0x46,0x0,0x75,0x0,0x6c,0x0,0x6c,0x0,
0x20,0x0,0x53,0x0,0x63,0x0,0x72,0x0,
0x65,0x0,0x65,0x0,0x6e,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x61,0x0,0x6e,0x0,0x64,0x0,0x61,0x0,
0x72,0x0,0x64,0x0,0x4b,0x0,0x65,0x0,
0x79,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x73,0x0,0x68,0x0,
0x6f,0x0,0x77,0x0,0x4e,0x0,0x6f,0x0,
0x72,0x0,0x6d,0x0,0x61,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x73,0x0,0x68,0x0,
0x6f,0x0,0x77,0x0,0x46,0x0,0x75,0x0,
0x6c,0x0,0x6c,0x0,0x53,0x0,0x63,0x0,
0x72,0x0,0x65,0x0,0x65,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x88,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x98,0x0,0x0,0x0,0x40,0x1,0x0,0x0,
0xc8,0x1,0x0,0x0,0x80,0x2,0x0,0x0,
0x9,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x60,0x0,0x0,0x0,
0x60,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x60,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa8,0x0,0x0,0x0,0xc,0x0,0x10,0x0,
0xd,0x0,0x50,0x0,0xa8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x10,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x12,0x0,0xc0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x14,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x19,0x0,0x50,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x84,0x0,0x0,0x0,0x14,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x84,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x90,0x0,
0x16,0x0,0x60,0x1,0x10,0x0,0x0,0x0,
0x0,0x0,0x3,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x15,0x0,0x90,0x0,
0x15,0x0,0x50,0x1,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x19,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x90,0x0,
0x20,0x0,0x60,0x1,0x1a,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x90,0x0,
0x1e,0x0,0x30,0x1,0x15,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x90,0x0,
0x1a,0x0,0xf0,0x0,0x17,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x90,0x0,
0x1d,0x0,0xe0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x1d,0x0,0x90,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x0,0x0,0x3,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x1d,0x0,0xe0,0x0,
0x1d,0x0,0x40,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for title at line 18, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QString v2_12;
QVariant v2_4;
QVariant v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadSingletonLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadSingletonLookup(0, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_4 = QVariant::fromValue(QStringLiteral("@action:menu"));
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_8 = QVariant::fromValue(QStringLiteral("Window"));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant retrieved;
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_4, &s.v2_8};
    return aotContext->callObjectPropertyLookup(1, s.v2_0, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(1, s.v2_0);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(17);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
retrieved = std::move(callResult);
aotContext->setImplicitDestructible(retrieved);
}
s.v2_12 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.v2_12);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QString>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for text at line 26, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_22, markStack);
    aotContext->mark(v2_26, markStack);
    aotContext->mark(v2_30, markStack);
    aotContext->mark(v2_41, markStack);
    aotContext->mark(v2_45, markStack);
    aotContext->mark(v2_49, markStack);
    aotContext->mark(v2_6, markStack);
    aotContext->mark(v2_8, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_22 = nullptr;
QObject *v2_41 = nullptr;
QObject *v2_6 = nullptr;
QObject *v2_8 = nullptr;
QString c2_58;
QString v2_34;
QString v2_53;
QVariant v2_10;
QVariant v2_26;
QVariant v2_30;
QVariant v2_45;
QVariant v2_49;
bool v2_18;
bool v2_2;
int v2_16;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(3, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
{
QObject * retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(4, s.v2_0, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(4, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
s.v2_2 = (std::move(retrieved) != nullptr);
}
{
}
// generate_JumpFalse
if (!s.v2_2) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->loadContextIdLookup(5, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initLoadContextIdLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getObjectLookup(6, s.v2_6, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetObjectLookup(6, s.v2_6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->getObjectLookup(7, s.v2_8, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initGetObjectLookupAsVariant(7, s.v2_8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getEnumLookup(9, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetEnumLookup(9, []() { static const auto t = QMetaType::fromName("QWindow*"); return t; }().metaObject(), "Visibility", "FullScreen");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_CmpStrictEqual
s.v2_18 = QJSPrimitiveValue(s.v2_16).strictlyEquals(aotContext->engine->fromVariant<QJSPrimitiveValue>(s.v2_10));
{
}
// generate_JumpFalse
if (!s.v2_18) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->loadSingletonLookup(10, &s.v2_22)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initLoadSingletonLookup(10, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_26 = QVariant::fromValue(QStringLiteral("@action:menu"));
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_30 = QVariant::fromValue(QStringLiteral("Exit Full Screen"));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant retrieved;
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_26, &s.v2_30};
    return aotContext->callObjectPropertyLookup(11, s.v2_22, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(11, s.v2_22);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(39);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(39);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
retrieved = std::move(callResult);
aotContext->setImplicitDestructible(retrieved);
}
s.v2_34 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
}
// generate_Jump
{
s.c2_58 = s.v2_34;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
while (!aotContext->loadSingletonLookup(12, &s.v2_41)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(43);
#endif
aotContext->initLoadSingletonLookup(12, QQmlPrivate::AOTCompiledContext::InvalidStringId);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_45 = QVariant::fromValue(QStringLiteral("@action:menu"));
{
}
// generate_StoreReg
{
}
// generate_LoadRuntimeString
s.v2_49 = QVariant::fromValue(QStringLiteral("Enter Full Screen"));
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant retrieved;
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult, &s.v2_45, &s.v2_49};
    return aotContext->callObjectPropertyLookup(13, s.v2_41, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(13, s.v2_41);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(58);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(58);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = QString();
}
return;
}
}
retrieved = std::move(callResult);
aotContext->setImplicitDestructible(retrieved);
}
s.v2_53 = aotContext->engine->fromVariant<QString>(std::move(retrieved));
}
{
s.c2_58 = s.v2_53;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QString *>(argv[0]) = std::move(s.c2_58);
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QVariant>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for shortcut at line 30, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QVariant v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(15, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(15, []() { static const auto t = QMetaType::fromName("QKeySequence"); return t; }().metaObject(), "StandardKey", "FullScreen");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QVariant *>(argv[0]) = QVariant();
}
return;
}
}
s.v2_2 = QVariant::fromValue(std::move(retrieved));
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_2.isValid())
        aotContext->setReturnValueUndefined();
    *static_cast<QVariant *>(argv[0]) = std::move(s.v2_2);
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onTriggered at line 32, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
    aotContext->mark(v2_11, markStack);
    aotContext->mark(v2_23, markStack);
    aotContext->mark(v2_25, markStack);
    aotContext->mark(v2_29, markStack);
    aotContext->mark(v2_38, markStack);
    aotContext->mark(v2_40, markStack);
    aotContext->mark(v2_44, markStack);
    aotContext->mark(v2_7, markStack);
    aotContext->mark(v2_9, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
QObject *v2_23 = nullptr;
QObject *v2_25 = nullptr;
QObject *v2_38 = nullptr;
QObject *v2_40 = nullptr;
QObject *v2_7 = nullptr;
QObject *v2_9 = nullptr;
QVariant v2_11;
QVariant v2_29;
QVariant v2_44;
bool v2_19;
bool v2_3;
int v2_17;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(16, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
QObject * retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
while (!aotContext->getObjectLookup(17, s.v2_1, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
aotContext->initGetObjectLookup(17, s.v2_1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_3 = (std::move(retrieved) != nullptr);
}
{
}
// generate_JumpFalse
if (!s.v2_3) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!aotContext->loadContextIdLookup(18, &s.v2_7)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
aotContext->initLoadContextIdLookup(18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(11);
#endif
while (!aotContext->getObjectLookup(19, s.v2_7, &s.v2_9)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(11);
#endif
aotContext->initGetObjectLookup(19, s.v2_7);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
while (!aotContext->getObjectLookup(20, s.v2_9, &s.v2_11)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
aotContext->initGetObjectLookupAsVariant(20, s.v2_9);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
while (!aotContext->getEnumLookup(22, &s.v2_17)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
aotContext->initGetEnumLookup(22, []() { static const auto t = QMetaType::fromName("QWindow*"); return t; }().metaObject(), "Visibility", "FullScreen");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_CmpStrictEqual
s.v2_19 = QJSPrimitiveValue(s.v2_17).strictlyEquals(aotContext->engine->fromVariant<QJSPrimitiveValue>(s.v2_11));
{
}
// generate_JumpFalse
if (!s.v2_19) {
    goto label_1;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(25);
#endif
while (!aotContext->loadContextIdLookup(23, &s.v2_23)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(25);
#endif
aotContext->initLoadContextIdLookup(23);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
while (!aotContext->getObjectLookup(24, s.v2_23, &s.v2_25)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
aotContext->initGetObjectLookup(24, s.v2_23);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(25, s.v2_25, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(25, s.v2_25);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_29 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_29);
}
{
}
{
}
// generate_Jump
{
    goto label_0;
}
label_1:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
while (!aotContext->loadContextIdLookup(26, &s.v2_38)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
aotContext->initLoadContextIdLookup(26);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
while (!aotContext->getObjectLookup(27, s.v2_38, &s.v2_40)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
aotContext->initGetObjectLookup(27, s.v2_38);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(28, s.v2_40, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookupAsVariant(28, s.v2_40);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(49);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(49);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_44 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_44);
}
{
}
{
}
label_0:;
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
